@@ -88,15 +88,15 @@ sub fetch
 	#   if the query takes too long, we should catch it and generate
 	#   an error
 	#
-	my $resp = Mail::DKIM::DNS::query($host, "TXT");
-	unless ($resp)
+	my @resp = Mail::DKIM::DNS::query($host, "TXT");
+	unless (@resp)
 	{
 		# no response => NXDOMAIN, use default policy
 		return $class->default;
 	}
 
 	my $strn;
-	foreach my $ans ($resp->answer) {
+	foreach my $ans (@resp) {
 		next unless $ans->type eq "TXT";
 		$strn = join "", $ans->char_str_list;
 	}
@@ -129,7 +129,8 @@ sub get_lookup_name
 	}
 	if ($prms->{Sender} && !$prms->{Domain})
 	{
-		(undef, $prms->{Domain}) = split(/\@/, $prms->{Sender}, 2);
+		# pick domain from email address
+		$prms->{Domain} = ($prms->{Sender} =~ /\@([^@]*)$/ and $1);
 	}
 
 	unless ($prms->{Domain})
